@@ -1,7 +1,7 @@
 """
 Type annotations for databrew service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_databrew/literals/)
 
 Usage::
 
@@ -61,7 +61,7 @@ CompressionFormatType = Literal[
 ]
 DatabaseOutputModeType = Literal["NEW_TABLE"]
 EncryptionModeType = Literal["SSE-KMS", "SSE-S3"]
-InputFormatType = Literal["CSV", "EXCEL", "JSON", "PARQUET"]
+InputFormatType = Literal["CSV", "EXCEL", "JSON", "ORC", "PARQUET"]
 JobRunStateType = Literal[
     "FAILED", "RUNNING", "STARTING", "STOPPED", "STOPPING", "SUCCEEDED", "TIMEOUT"
 ]
@@ -322,6 +322,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
